@@ -1,25 +1,26 @@
 import sys
 from collections import defaultdict
 import threading
+
 try:
     from itertools import zip_longest
 except ImportError:
     from itertools import izip_longest as zip_longest
 
-from wfuzz.fuzzobjects import FuzzResult
+from wfuzz.fuzzobjects import FuzzWordType, FuzzType
 
 from .common import exec_banner, Term
 from .getch import _Getch
-from .output import getTerminalSize, wrap_always
+from .output import getTerminalSize, wrap_always_list
 
-usage = '''\r\n
+usage = """\r\n
 Interactive keyboard commands:\r\n
 ?: Show this help
 
 p: Pause
 s: Show stats
 q: Cancel
-'''
+"""
 
 
 class SimpleEventDispatcher:
@@ -31,13 +32,13 @@ class SimpleEventDispatcher:
 
     def subscribe(self, func, msg, dynamic=False):
         if msg not in self.publisher and not dynamic:
-            raise KeyError('subscribe. No such event: %s' % (msg))
+            raise KeyError("subscribe. No such event: %s" % (msg))
         else:
             self.publisher[msg].append(func)
 
     def notify(self, msg, **event):
         if msg not in self.publisher:
-            raise KeyError('notify. Event not subscribed: %s' % (msg,))
+            raise KeyError("notify. Event not subscribed: %s" % (msg,))
         else:
             for functor in self.publisher[msg]:
                 functor(**event)
@@ -65,13 +66,13 @@ class KeyPress(threading.Thread):
             k = self.inkey()
             if k and ord(k) == 3:
                 self.dispatcher.notify("q", key="q")
-            elif k == 'p':
+            elif k == "p":
                 self.dispatcher.notify("p", key="p")
-            elif k == 's':
+            elif k == "s":
                 self.dispatcher.notify("s", key="s")
-            elif k == '?':
+            elif k == "?":
                 self.dispatcher.notify("?", key="?")
-            elif k == 'q':
+            elif k == "q":
                 self.dispatcher.notify("q", key="q")
 
 
@@ -118,18 +119,30 @@ class Controller:
                 print("%s: %s" % (k, v))
             print("\n=========================================")
         else:
-            pending = self.fuzzer.genReq.stats.total_req - self.fuzzer.genReq.stats.processed()
+            pending = (
+                self.fuzzer.genReq.stats.total_req
+                - self.fuzzer.genReq.stats.processed()
+            )
             summary = self.fuzzer.genReq.stats
             summary.mark_end()
             print("\nTotal requests: %s\r" % str(summary.total_req))
             print("Pending requests: %s\r" % str(pending))
 
             if summary.backfeed() > 0:
-                print("Processed Requests: %s (%d + %d)\r" % (str(summary.processed())[:8], (summary.processed() - summary.backfeed()), summary.backfeed()))
+                print(
+                    "Processed Requests: %s (%d + %d)\r"
+                    % (
+                        str(summary.processed())[:8],
+                        (summary.processed() - summary.backfeed()),
+                        summary.backfeed(),
+                    )
+                )
             else:
                 print("Processed Requests: %s\r" % (str(summary.processed())[:8]))
             print("Filtered Requests: %s\r" % (str(summary.filtered())[:8]))
-            req_sec = summary.processed() / summary.totaltime if summary.totaltime > 0 else 0
+            req_sec = (
+                summary.processed() / summary.totaltime if summary.totaltime > 0 else 0
+            )
             print("Total time: %s\r" % str(summary.totaltime)[:8])
             if req_sec > 0:
                 print("Requests/sec.: %s\r" % str(req_sec)[:8])
@@ -149,33 +162,38 @@ class View:
         self.verbose = session_options["verbose"]
         self.previous = session_options["previous"]
         self.term = Term()
-        self.printed_lines = 1
+        self.printed_lines = 0
 
     def _print_verbose(self, res, print_nres=True):
-        txt_colour = Term.noColour if not res.is_baseline or not self.colour else Term.fgCyan
+        txt_colour = (
+            Term.noColour if not res.is_baseline or not self.colour else Term.fgCyan
+        )
         if self.previous and self.colour and not print_nres:
             txt_colour = Term.fgCyan
 
         location = ""
-        if 'Location' in res.history.headers.response:
-            location = res.history.headers.response['Location']
+        if "Location" in res.history.headers.response:
+            location = res.history.headers.response["Location"]
         elif res.history.url != res.history.redirect_url:
             location = "(*) %s" % res.history.url
 
         server = ""
-        if 'Server' in res.history.headers.response:
-            server = res.history.headers.response['Server']
+        if "Server" in res.history.headers.response:
+            server = res.history.headers.response["Server"]
 
         rows = [
             ("%09d:" % res.nres if print_nres else " |_", txt_colour),
             ("%.3fs" % res.timer, txt_colour),
-            ("%s" % "XXX" if res.exception else str(res.code), self.term.get_colour(res.code) if self.colour else txt_colour),
+            (
+                "%s" % "XXX" if res.exception else str(res.code),
+                self.term.get_colour(res.code) if self.colour else txt_colour,
+            ),
             ("%d L" % res.lines, txt_colour),
             ("%d W" % res.words, txt_colour),
             ("%d Ch" % res.chars, txt_colour),
             (server, txt_colour),
             (location, txt_colour),
-            ("\"%s\"" % res.description, txt_colour),
+            ('"%s"' % res.description, txt_colour),
         ]
 
         self.term.set_colour(txt_colour)
@@ -184,39 +202,54 @@ class View:
     def _print_header(self, rows, maxWidths):
         print("=" * (3 * len(maxWidths) + sum(maxWidths[:-1]) + 10))
         self._print_line(rows, maxWidths)
-        sys.stdout.write("\n\r")
         print("=" * (3 * len(maxWidths) + sum(maxWidths[:-1]) + 10))
         print("")
 
     def _print_line(self, rows, maxWidths):
         def wrap_row(rows, maxWidths):
-            newRows = [wrap_always(item[0], width).split('\n') for item, width in zip(rows, maxWidths)]
-            return [[substr or '' for substr in item] for item in zip_longest(*newRows)]
+            newRows = [
+                wrap_always_list(item[0], width) for item, width in zip(rows, maxWidths)
+            ]
+            return [[substr or "" for substr in item] for item in zip_longest(*newRows)]
+
+        def print_row(row, rows):
+            sys.stdout.write(
+                "   ".join(
+                    [
+                        colour + str.ljust(str(item), width) + Term.reset
+                        for (item, width, colour) in zip(
+                            row, maxWidths, [colour[1] for colour in rows]
+                        )
+                    ]
+                )
+            )
 
         new_rows = wrap_row(rows, maxWidths)
 
-        for row in new_rows[:-1]:
-            sys.stdout.write("   ".join([colour + str.ljust(str(item), width) + Term.reset for (item, width, colour) in zip(row, maxWidths, [colour[1] for colour in rows])]))
+        for row in new_rows:
+            print_row(row, rows)
             sys.stdout.write("\n\r")
 
-        for row in new_rows[-1:]:
-            sys.stdout.write("   ".join([colour + str.ljust(str(item), width) + Term.reset for (item, width, colour) in zip(row, maxWidths, [colour[1] for colour in rows])]))
-
         sys.stdout.flush()
         return len(new_rows)
 
     def _print(self, res, print_nres=True):
-        txt_colour = Term.noColour if not res.is_baseline or not self.colour else Term.fgCyan
+        txt_colour = (
+            Term.noColour if not res.is_baseline or not self.colour else Term.fgCyan
+        )
         if self.previous and self.colour and not print_nres:
             txt_colour = Term.fgCyan
 
         rows = [
             ("%09d:" % res.nres if print_nres else " |_", txt_colour),
-            ("%s" % "XXX" if res.exception else str(res.code), self.term.get_colour(res.code) if self.colour else txt_colour),
+            (
+                "%s" % "XXX" if res.exception else str(res.code),
+                self.term.get_colour(res.code) if self.colour else txt_colour,
+            ),
             ("%d L" % res.lines, txt_colour),
             ("%d W" % res.words, txt_colour),
             ("%d Ch" % res.chars, txt_colour),
-            ("\"%s\"" % res.description, txt_colour),
+            ('"%s"' % res.description, txt_colour),
         ]
 
         self.term.set_colour(txt_colour)
@@ -260,37 +293,34 @@ class View:
         self._print_header(rows, widths)
 
     def result(self, res):
-        self.term.erase_lines(self.printed_lines)
-
         if self.verbose:
             self._print_verbose(res)
         else:
             self._print(res)
 
-        if res.type == FuzzResult.result:
-            if self.previous and len(res.payload) > 0 and isinstance(res.payload[0].content, FuzzResult):
-                sys.stdout.write("\n\r")
+        if res.item_type == FuzzType.RESULT:
+            if (
+                self.previous
+                and res.payload_man
+                and res.payload_man.get_payload_type(1) == FuzzWordType.FUZZRES
+            ):
+                prev_res = res.payload_man.get_payload_content(1)
                 if self.verbose:
-                    self._print_verbose(res.payload[0].content, print_nres=False)
+                    self._print_verbose(prev_res, print_nres=False)
                 else:
-                    self._print(res.payload[0].content, print_nres=False)
+                    self._print(prev_res, print_nres=False)
 
             if res.plugins_res:
-                sys.stdout.write("\n\r")
-
-                for i in res.plugins_res[:-1]:
+                for i in res.plugins_res:
                     sys.stdout.write(" |_  %s\r" % i.issue)
                     sys.stdout.write("\n\r")
 
-                for i in res.plugins_res[-1:]:
-                    sys.stdout.write(" |_  %s\r" % i.issue)
+            self.printed_lines = 0
 
-            for i in range(self.printed_lines):
-                sys.stdout.write("\n\r")
+        if self.printed_lines > 0:
+            self.term.erase_lines(self.printed_lines + 1)
 
     def footer(self, summary):
-        self.term.erase_lines(self.printed_lines + 1)
-        sys.stdout.write("\n\r")
         sys.stdout.write("\n\r")
 
         print(summary)
